@@ -1,24 +1,23 @@
 // -*- c++ -*- (enables emacs c++ mode)
-//========================================================================
+//===========================================================================
 //
-// Copyright (C) 2001-2006 Y. Renard, J. Pommier.
+// Copyright (C) 2001-2008 Y. Renard, J. Pommier.
 //
 // This file is a part of GETFEM++
 //
-// Getfem++ is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// Getfem++  is  free software;  you  can  redistribute  it  and/or modify it
+// under  the  terms  of the  GNU  Lesser General Public License as published
+// by  the  Free Software Foundation;  either version 2.1 of the License,  or
+// (at your option) any later version.
+// This program  is  distributed  in  the  hope  that it will be useful,  but
+// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+// or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
+// You  should  have received a copy of the GNU Lesser General Public License
+// along  with  this program;  if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-// You should have received a copy of the GNU Lesser General Public
-// License along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-// USA.
-//
-//========================================================================
+//===========================================================================
 
 /**\file gf_mdbrick_set.cc
    \brief getfemint_mdbrick getter.
@@ -52,7 +51,7 @@ using namespace getfemint;
   @GET MDBRICK:GET('tresca')
   @GET MDBRICK:GET('memsize')
 
-  $Id: gf_mdbrick_get.cc 2658 2007-07-24 13:28:17Z chahineelie $
+  $Id: gf_mdbrick_get.cc 2722 2007-12-04 15:26:17Z renard $
 MLABCOM*/
 void gf_mdbrick_get(getfemint::mexargs_in& in, getfemint::mexargs_out& out)
 {
