@@ -1,24 +1,23 @@
 // -*- c++ -*- (enables emacs c++ mode)
-//========================================================================
+//===========================================================================
 //
-// Copyright (C) 2006-2006 Yves Renard, Julien Pommier.
+// Copyright (C) 2006-2008 Yves Renard, Julien Pommier.
 //
 // This file is a part of GETFEM++
 //
-// Getfem++ is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// Getfem++  is  free software;  you  can  redistribute  it  and/or modify it
+// under  the  terms  of the  GNU  Lesser General Public License as published
+// by  the  Free Software Foundation;  either version 2.1 of the License,  or
+// (at your option) any later version.
+// This program  is  distributed  in  the  hope  that it will be useful,  but
+// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+// or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
+// You  should  have received a copy of the GNU Lesser General Public License
+// along  with  this program;  if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-// You should have received a copy of the GNU Lesser General Public
-// License along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-// USA.
-//
-//========================================================================
+//===========================================================================
 
 #include <map>
 #include <getfemint_misc.h>
@@ -255,7 +254,7 @@ normal_of_face(const getfem::mesh& mesh, size_type cv, bgeot::dim_type f, size_t
   @GET    MESH:GET('export to dx')
   @GET    MESH:GET('memsize')
 
-  $Id: gf_mesh_get.cc 2659 2007-07-25 11:03:54Z pommier $
+  $Id: gf_mesh_get.cc 2722 2007-12-04 15:26:17Z renard $
 MLABCOM*/
 
 
