@@ -1,30 +1,29 @@
 // -*- c++ -*- (enables emacs c++ mode)
-//========================================================================
+//===========================================================================
 //
-// Copyright (C) 2006-2006 Yves Renard, Julien Pommier.
+// Copyright (C) 2006-2008 Yves Renard, Julien Pommier.
 //
 // This file is a part of GETFEM++
 //
-// Getfem++ is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// Getfem++  is  free software;  you  can  redistribute  it  and/or modify it
+// under  the  terms  of the  GNU  Lesser General Public License as published
+// by  the  Free Software Foundation;  either version 2.1 of the License,  or
+// (at your option) any later version.
+// This program  is  distributed  in  the  hope  that it will be useful,  but
+// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+// or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
+// You  should  have received a copy of the GNU Lesser General Public License
+// along  with  this program;  if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-// You should have received a copy of the GNU Lesser General Public
-// License along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-// USA.
-//
-//========================================================================
+//===========================================================================
 
 #include <getfemint_misc.h>
 #include <getfemint_mesh_im.h>
 #include <getfemint_integ.h>
 /*
-  $Id: gf_mesh_im_get.cc 2659 2007-07-25 11:03:54Z pommier $
+  $Id: gf_mesh_im_get.cc 2722 2007-12-04 15:26:17Z renard $
 
   ChangeLog:
   $Log: gf_mesh_im_get.cc,v $
@@ -80,7 +79,7 @@ get_integ_of_convexes(const getfem::mesh_im& mim, mexargs_in& in, mexargs_out& o
   @GET    MESHIM:GET('linked mesh')
   @GET    MESHIM:GET('memsize')
 
-  $Id: gf_mesh_im_get.cc 2659 2007-07-25 11:03:54Z pommier $
+  $Id: gf_mesh_im_get.cc 2722 2007-12-04 15:26:17Z renard $
 MLABCOM*/
 
 void gf_mesh_im_get(getfemint::mexargs_in& in, getfemint::mexargs_out& out)
