@@ -1,24 +1,32 @@
 // -*- c++ -*- (enables emacs c++ mode)
-//========================================================================
+//===========================================================================
 //
-// Copyright (C) 2004-2007 Yves Renard
+// Copyright (C) 2004-2008 Yves Renard
 //
 // This file is a part of GETFEM++
 //
-// Getfem++ is free software; you can redistribute it and/or modify
-// it under the terms of the GNU Lesser General Public License as
-// published by the Free Software Foundation; version 2.1 of the License.
+// Getfem++  is  free software;  you  can  redistribute  it  and/or modify it
+// under  the  terms  of the  GNU  Lesser General Public License as published
+// by  the  Free Software Foundation;  either version 2.1 of the License,  or
+// (at your option) any later version.
+// This program  is  distributed  in  the  hope  that it will be useful,  but
+// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+// or  FITNESS  FOR  A PARTICULAR PURPOSE.  See the GNU Lesser General Public
+// License for more details.
+// You  should  have received a copy of the GNU Lesser General Public License
+// along  with  this program;  if not, write to the Free Software Foundation,
+// Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301, USA.
 //
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU Lesser General Public License for more details.
-// You should have received a copy of the GNU Lesser General Public
-// License along with this program; if not, write to the Free Software
-// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301,
-// USA.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.
 //
-//========================================================================
+//===========================================================================
 
 /**
    @file getfem_modeling.h
@@ -882,6 +890,7 @@ namespace getfem {
 
     void proper_update_K(void) {
       GMM_TRACE2("Assembling mass matrix for mdbrick_mass_matrix");
+      gmm::clear(this->K);
       asm_mass_matrix_param
 	(this->K, this->mim, this->mf_u, rho().mf(), rho().get(), 
 	 this->mf_u.linked_mesh().get_mpi_region());
@@ -929,6 +938,7 @@ namespace getfem {
       VECTOR w(wave_number().get());
       for (unsigned i=0; i < gmm::vect_size(w); ++i) 
 	w[i] = gmm::sqr(w[i]);
+      gmm::clear(this->K);
       asm_Helmholtz(this->K, this->mim, this->mf_u, wave_number().mf(), w,
 		    this->mf_u.linked_mesh().get_mpi_region());
     }
@@ -986,6 +996,7 @@ namespace getfem {
     mdbrick_parameter<VECTOR> coeff_;
 
     void proper_update_K(void) {
+      gmm::clear(this->K);
       if (coeff_.fdim() == 0) {
 	if (this->mf_u.get_qdim() > 1)
 	  asm_stiffness_matrix_for_laplacian_componentwise(this->K, this->mim, this->mf_u,
@@ -1100,6 +1111,7 @@ namespace getfem {
 	const mesh_fem &mf_u = *(this->mesh_fems[num_fem]);
 	F_uptodate = true;
 	GMM_TRACE2("Assembling a source term");
+	gmm::clear(F_);
 	asm_source_term(F_, *(this->mesh_ims[0]), mf_u, B_.mf(), B_.get(),
 			mf_u.linked_mesh().get_mpi_sub_region(boundary));
 	this->parameters_set_uptodate();
@@ -1213,6 +1225,7 @@ namespace getfem {
       if (!F_uptodate || this->parameters_is_any_modified()) {
 	F_uptodate = true;
 	GMM_TRACE2("Assembling a source term");
+	gmm::clear(F_);
 	asm_normal_source_term
 	  (F_, *(this->mesh_ims[0]), mf_u(), B_.mf(), B_.get(),
 	   mf_u().linked_mesh().get_mpi_sub_region(boundary));
@@ -2207,6 +2220,7 @@ namespace getfem {
 
     void proper_update_M(void) {
       GMM_TRACE2("Assembling mass matrix for mdbrick_dynamic");
+      gmm::clear(M_);
       asm_mass_matrix_param(M_, *(this->mesh_ims[0]), *mf_u, RHO_.mf(),
 			    RHO_.get());
 
